==> haskell-fdo-notify-0.3.1-64-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-spOuDxG4lN6d6bTf8O66J
key: fdo-notify-0.3.1-spOuDxG4lN6d6bTf8O66J
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: c2a5a132f594994cc9a5620ec370f0f3
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-spOuDxG4lN6d6bTf8O66J
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-BnI7FSCQ4Wm1haMMVlYvdQ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             dbus-1.0.1-BnI7FSCQ4Wm1haMMVlYvdQ=c6cf4e2d1d8842c18b2aeebded40bc48
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-76-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-40zW4BY0Zn9yI8DruRybO
key: fdo-notify-0.3.1-40zW4BY0Zn9yI8DruRybO
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: 4c3ddc6c45537db6f8fe968ee0bbb77a
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-40zW4BY0Zn9yI8DruRybO
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-JaPiRiYoi5i3FXNFfiUgHc
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             dbus-1.0.1-JaPiRiYoi5i3FXNFfiUgHc=840853c119c7143d4e40ecfd25e123d2
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
